@@ -12,7 +12,7 @@ import System.FilePath
 import Data.Char
 import Data.Time.Clock
 
-import Development.Shake hiding (withTempDir)
+import Development.Shake.Fancy hiding (withTempDir)
 
 
 -- This is copied from extra and shake sources, because they do not allow to
